=== modified file 'AgendaView.qml'
--- AgendaView.qml	2014-09-16 07:39:40 +0000
+++ AgendaView.qml	2014-09-19 08:11:17 +0000
@@ -15,8 +15,8 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-import QtQuick 2.0
-import Ubuntu.Components 0.1
+import QtQuick 2.3
+import Ubuntu.Components 1.1
 import QtOrganizer 5.0
 
 import "dateExt.js" as DateExt
@@ -42,6 +42,23 @@
 
         return !!enabled_calendars.length;
     }
+    Action {
+           id: calendarTodayAction
+           objectName:"todaybutton"
+           iconName: "calendar-today"
+           text: i18n.tr("Today")
+           onTriggered: {
+               currentDay = new Date()
+               goToBeginning()
+           }
+       }
+
+       head.actions: [
+           calendarTodayAction,
+           commonHeaderActions.newEventAction,
+           commonHeaderActions.showCalendarAction,
+           commonHeaderActions.reloadAction
+       ]
 
     EventListModel {
         id: eventListModel

=== modified file 'DayView.qml'
--- DayView.qml	2014-09-02 00:02:38 +0000
+++ DayView.qml	2014-09-19 08:11:17 +0000
@@ -30,6 +30,23 @@
 
     Keys.forwardTo: [dayViewPath]
     flickable: null
+    Action {
+           id: calendarTodayAction
+           objectName:"todaybutton"
+           iconName: "calendar-today"
+           text: i18n.tr("Today")
+           onTriggered: {
+               currentDay = new Date()
+               goToBeginning()
+           }
+       }
+
+       head.actions: [
+           calendarTodayAction,
+           commonHeaderActions.newEventAction,
+           commonHeaderActions.showCalendarAction,
+           commonHeaderActions.reloadAction
+       ]
 
     Column {
         id: column

=== added file 'EventActions.qml'
--- EventActions.qml	1970-01-01 00:00:00 +0000
+++ EventActions.qml	2014-09-19 08:11:17 +0000
@@ -0,0 +1,59 @@
+/*
+ * Copyright (C) 2014 Canonical Ltd
+ *
+ * This file is part of Ubuntu Calendar App
+ *
+ * Ubuntu Calendar App is free software: you can redistribute it and/or modify
+ * it under the terms of the GNU General Public License version 3 as
+ * published by the Free Software Foundation.
+ *
+ * Ubuntu Calendar App is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+ * GNU General Public License for more details.
+ *
+ * You should have received a copy of the GNU General Public License
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ */
+
+import QtQuick 2.3
+import Ubuntu.Components 1.1
+
+Item {
+    id: actionPool
+
+    property alias newEventAction: _newEventAction
+    property alias showCalendarAction: _showCalendarAction
+    property alias reloadAction: _reloadAction
+
+    Action {
+        id: _newEventAction
+        objectName: "neweventbutton"
+        iconName: "new-event"
+        text: i18n.tr("New Event")
+        onTriggered: {
+            pageStack.push(Qt.resolvedUrl("NewEvent.qml"),{"date":tabs.currentDay,"model":eventModel});
+        }
+    }
+
+    Action{
+        id: _showCalendarAction
+        iconName: "new-event"
+        text: i18n.tr("Calendars")
+        onTriggered: {
+            pageStack.push(Qt.resolvedUrl("CalendarChoicePopup.qml"),{"model":eventModel});
+            pageStack.currentPage.collectionUpdated.connect(eventModel.delayedApplyFilter);
+        }
+    }
+
+    // #FIXME: This  action doesn't seem to be visible!
+    Action {
+        id: _reloadAction
+        objectName: "syncbutton"
+        iconName: "reload"
+        text: enabled ? i18n.tr("Sync") : i18n.tr("Syncing")
+        onTriggered: syncMonitor.sync(["calendar"])
+        enabled: (syncMonitor.state !== "syncing")
+        visible: syncMonitor.enabledServices ? syncMonitor.serviceIsEnabled("calendar") : false
+    }
+}

=== modified file 'MonthView.qml'
--- MonthView.qml	2014-09-02 00:02:38 +0000
+++ MonthView.qml	2014-09-19 08:11:17 +0000
@@ -29,6 +29,23 @@
     signal dateSelected(var date);
 
     Keys.forwardTo: [monthViewPath]
+    Action {
+           id: calendarTodayAction
+           objectName:"todaybutton"
+           iconName: "calendar-today"
+           text: i18n.tr("Today")
+           onTriggered: {
+               currentDay = new Date()
+               goToBeginning()
+           }
+       }
+
+       head.actions: [
+           calendarTodayAction,
+           commonHeaderActions.newEventAction,
+           commonHeaderActions.showCalendarAction,
+           commonHeaderActions.reloadAction
+       ]
 
     PathViewBase{
         id: monthViewPath

=== modified file 'WeekView.qml'
--- WeekView.qml	2014-09-02 00:02:38 +0000
+++ WeekView.qml	2014-09-19 08:11:17 +0000
@@ -34,6 +34,23 @@
     Keys.forwardTo: [weekViewPath]
 
     flickable: null
+    Action {
+           id: calendarTodayAction
+           objectName:"todaybutton"
+           iconName: "calendar-today"
+           text: i18n.tr("Today")
+           onTriggered: {
+               currentDay = new Date()
+               goToBeginning()
+           }
+       }
+
+       head.actions: [
+           calendarTodayAction,
+           commonHeaderActions.newEventAction,
+           commonHeaderActions.showCalendarAction,
+           commonHeaderActions.reloadAction
+       ]
 
     Column {
         anchors.fill: parent

=== modified file 'YearView.qml'
--- YearView.qml	2014-09-08 10:21:19 +0000
+++ YearView.qml	2014-09-19 08:11:17 +0000
@@ -27,6 +27,23 @@
     signal monthSelected(var date);
 
     Keys.forwardTo: [yearPathView]
+    Action {
+           id: calendarTodayAction
+           objectName:"todaybutton"
+           iconName: "calendar-today"
+           text: i18n.tr("Today")
+           onTriggered: {
+               currentDay = new Date()
+               goToBeginning()
+           }
+       }
+
+       head.actions: [
+           calendarTodayAction,
+           commonHeaderActions.newEventAction,
+           commonHeaderActions.showCalendarAction,
+           commonHeaderActions.reloadAction
+       ]
 
     PathViewBase {
         id: yearPathView

=== modified file 'calendar.qml'
--- calendar.qml	2014-09-09 10:46:02 +0000
+++ calendar.qml	2014-09-19 08:11:17 +0000
@@ -15,7 +15,7 @@
  * You should have received a copy of the GNU General Public License
  * along with this program.  If not, see <http://www.gnu.org/licenses/>.
  */
-import QtQuick 2.0
+import QtQuick 2.3
 import Ubuntu.Components 1.1
 import Ubuntu.Components.Popups 1.0
 import QtOrganizer 5.0
@@ -28,7 +28,7 @@
     useDeprecatedToolbar: false
 
     // Work-around until this branch lands:
-    // https://code.launchpad.net/~tpeeters/ubuntu-ui-toolkit/optIn-tabsDrawer/+merge/212496 
+    // https://code.launchpad.net/~tpeeters/ubuntu-ui-toolkit/optIn-tabsDrawer/+merge/212496
     //property bool windowActive: typeof window != 'undefined'
     //onWindowActiveChanged: window.title = i18n.tr("Calendar")
 
@@ -294,58 +294,8 @@
                 }
             } // End of Component.onCompleted:
 
-            ToolbarItems {
-                id: commonToolBar
-
-                ToolbarButton {
-                    action: Action {
-                        iconName: "calendar-today"
-
-                        text: i18n.tr("Today");
-                        objectName: "todaybutton"
-                        onTriggered: {
-                            tabs.currentDay = (new Date()).midnight();
-                            if(yearViewLoader.item ) yearViewLoader.item.currentYear = tabs.currentDay.getFullYear();
-                            if(monthViewLoader.item ) monthViewLoader.item.currentMonth = tabs.currentDay.midnight();
-                            if(weekViewLoader.item ) weekViewLoader.item.dayStart = tabs.currentDay;
-                            if(dayViewLoader.item ) dayViewLoader.item.currentDay = tabs.currentDay;
-                            if(agendaViewLoader.item ) {
-                                agendaViewLoader.item.currentDay = tabs.currentDay;
-                                agendaViewLoader.item.goToBeginning();
-                            }
-                        }
-                    }
-                }
-                ToolbarButton {
-                    action: Action {
-                        objectName: "neweventbutton"
-                        iconName: "new-event"
-                        text: i18n.tr("New Event");
-                        onTriggered: {
-                            pageStack.push(Qt.resolvedUrl("NewEvent.qml"),{"date":tabs.currentDay,"model":eventModel});
-                        }
-                    }
-                }
-                ToolbarButton{
-                    action:Action{
-                        iconName: "new-event"
-                        text: i18n.tr("Calendars");
-                        onTriggered: {
-                            pageStack.push(Qt.resolvedUrl("CalendarChoicePopup.qml"),{"model":eventModel});
-                            pageStack.currentPage.collectionUpdated.connect(eventModel.delayedApplyFilter);
-                        }
-                    }
-                }
-                ToolbarButton {
-                    objectName: "syncbutton"
-                    visible: syncMonitor.enabledServices ? syncMonitor.serviceIsEnabled("calendar") : false
-                    action: Action {
-                        text: enabled ? i18n.tr("Sync") : i18n.tr("Syncing")
-                        iconName: "reload"
-                        onTriggered: syncMonitor.sync(["calendar"])
-                        enabled: (syncMonitor.state !== "syncing")
-                    }
-                }
+            EventActions {
+                id: commonHeaderActions
             }
 
             Keys.onTabPressed: {
@@ -379,7 +329,6 @@
                     objectName: "yearViewLoader"
                     source: tabs.selectedTab == yearTab ? Qt.resolvedUrl("YearView.qml"):""
                     onLoaded: {
-                        item.tools = Qt.binding(function() { return commonToolBar })
                         item.currentYear = tabs.currentDay.getFullYear();
                     }
 
@@ -414,7 +363,6 @@
                     objectName: "monthViewLoader"
                     source: tabs.selectedTab == monthTab ? Qt.resolvedUrl("MonthView.qml"):""
                     onLoaded: {
-                        item.tools = Qt.binding(function() { return commonToolBar })
                         item.currentMonth = tabs.currentDay.midnight();
                     }
 
@@ -443,7 +391,6 @@
                     objectName: "weekViewLoader"
                     source: tabs.selectedTab == weekTab ? Qt.resolvedUrl("WeekView.qml"):""
                     onLoaded: {
-                        item.tools = Qt.binding(function() { return commonToolBar })
                         item.isCurrentPage= Qt.binding(function() { return tabs.selectedTab == weekTab })
                         item.dayStart = tabs.currentDay;
                     }
@@ -477,7 +424,6 @@
                     objectName: "dayViewLoader"
                     source: tabs.selectedTab == dayTab ? Qt.resolvedUrl("DayView.qml"):""
                     onLoaded: {
-                        item.tools = Qt.binding(function() { return commonToolBar })
                         item.isCurrentPage= Qt.binding(function() { return tabs.selectedTab == dayTab })
                         item.currentDay = tabs.currentDay;
                     }
@@ -507,7 +453,6 @@
                     source: tabs.selectedTab == agendaTab ? Qt.resolvedUrl("AgendaView.qml"):""
 
                     onLoaded: {
-                        item.tools = Qt.binding(function() { return commonToolBar })
                         item.currentDay = tabs.currentDay;
                     }
 

